#ifndef __nta_item_h_
#define __nta_item_h_

/**
	This is a helper class to encapsulate a News Text Analytics item sent via OMM as one or more fragments
*/

#include "Ema.h"
#include <string>

class NTAItem
{
public:
	NTAItem();
	~NTAItem();

	// Initialise instance with Update field list
	void init(const refinitiv::ema::access::FieldList& envelope);
	
	// Append an additional fragments to this instance
	void addFragment(const NTAItem& fragment);
	
	// Have we received all the fragments i.e. TOT_SIZE number of bytes ?
	bool isComplete() const { return (_expectedSize > 0) && (_expectedSize == _ntaBuffer.size()); };

	const std::string& getBuffer() const { return _ntaBuffer; };

	const refinitiv::ema::access::EmaString& getGUID() const { return _guid; };
	const refinitiv::ema::access::EmaString& getSource() const{ return _mrnSource; };
	const refinitiv::ema::access::EmaString& getType() const{ return _mrnType; };
	refinitiv::ema::access::UInt64 getFragNum() const { return _fragNum; };

private:
	std::string _ntaBuffer;
	refinitiv::ema::access::EmaString _guid;
	refinitiv::ema::access::EmaString _mrnSource;
	refinitiv::ema::access::EmaString _mrnType;
	refinitiv::ema::access::UInt64 _fragNum;
	refinitiv::ema::access::UInt64 _expectedSize;

};

#endif // __nta_item_h_